summaryrefslogtreecommitdiff
path: root/src/tile_cmd.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/tile_cmd.h')
-rw-r--r--src/tile_cmd.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/tile_cmd.h b/src/tile_cmd.h
index ce70232a0..855aa297d 100644
--- a/src/tile_cmd.h
+++ b/src/tile_cmd.h
@@ -168,29 +168,29 @@ void GetTileDesc(TileIndex tile, TileDesc *td);
static inline void AddAcceptedCargo(TileIndex tile, CargoArray &acceptance, CargoTypes *always_accepted)
{
AddAcceptedCargoProc *proc = _tile_type_procs[GetTileType(tile)]->add_accepted_cargo_proc;
- if (proc == NULL) return;
- CargoTypes dummy = 0; // use dummy bitmask so there don't need to be several 'always_accepted != NULL' checks
- proc(tile, acceptance, always_accepted == NULL ? &dummy : always_accepted);
+ if (proc == nullptr) return;
+ CargoTypes dummy = 0; // use dummy bitmask so there don't need to be several 'always_accepted != nullptr' checks
+ proc(tile, acceptance, always_accepted == nullptr ? &dummy : always_accepted);
}
static inline void AddProducedCargo(TileIndex tile, CargoArray &produced)
{
AddProducedCargoProc *proc = _tile_type_procs[GetTileType(tile)]->add_produced_cargo_proc;
- if (proc == NULL) return;
+ if (proc == nullptr) return;
proc(tile, produced);
}
static inline void AnimateTile(TileIndex tile)
{
AnimateTileProc *proc = _tile_type_procs[GetTileType(tile)]->animate_tile_proc;
- assert(proc != NULL);
+ assert(proc != nullptr);
proc(tile);
}
static inline bool ClickTile(TileIndex tile)
{
ClickTileProc *proc = _tile_type_procs[GetTileType(tile)]->click_tile_proc;
- if (proc == NULL) return false;
+ if (proc == nullptr) return false;
return proc(tile);
}